.. cellpose-napari documentation master file, created by
   sphinx-quickstart on Thu Oct  1 00:43:18 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

cellpose-napari
===============================================================

cellpose-napari is a plugin to enable usage of cellpose in napari.

.. image:: _static/gui.PNG
    :width: 1200px
    :align: center
    :alt: plugin

Please see cellpose `documentation`_ for more information on the 
algorithm and the settings.

If you use this plugin please cite 
::
    
      @article{stringer2021cellpose,
      title={Cellpose: a generalist algorithm for cellular segmentation},
      author={Stringer, Carsen and Wang, Tim and Michaelos, Michalis and Pachitariu, Marius},
      journal={Nature Methods},
      volume={18},
      number={1},
      pages={100--106},
      year={2021},
      publisher={Nature Publishing Group}
      }


.. _documentation: http://www.readthedocs.cellpose.io


.. toctree::
   :maxdepth: 3
   :caption: Basics:
   
   installation
   running
   settings
